pub struct ReusedHttpStream { /* private fields */ }Implementations
Sourceimpl ReusedHttpStream
impl ReusedHttpStream
pub fn new( stream: Stream, persistent_settings: Option<HttpPersistentSettings>, ) -> Self
Sourcepub fn from_reusable_stream(
reusable: ReusableHttpStream,
persistent_settings: HttpPersistentSettings,
) -> Self
pub fn from_reusable_stream( reusable: ReusableHttpStream, persistent_settings: HttpPersistentSettings, ) -> Self
Build a reusable HTTP stream from a finished session, preserving any pipelined prefix bytes in the persistent settings for the next request.
pub fn consume(self) -> (Stream, Option<HttpPersistentSettings>)