pub struct ReusableHttpStream { /* private fields */ }Expand description
A reusable HTTP/1.x stream and bytes already read for the next request.
Implementations
Sourceimpl ReusableHttpStream
impl ReusableHttpStream
Sourcepub fn into_parts(self) -> (Stream, Option<BytesMut>)
pub fn into_parts(self) -> (Stream, Option<BytesMut>)
Split the reusable connection into its underlying stream and optional bytes already read for the next pipelined request.