Stream

Struct Stream 

pub struct Stream {
    pub established_ts: SystemTime,
    pub tracer: Option<Tracer>,
    pub rx_ts: Option<SystemTime>,
    /* private fields */
}
A concrete type for transport layer connection + extra fields for logging

Fields

established_ts: SystemTime

When this connection is established

tracer: Option<Tracer>

The distributed tracing object for this stream

rx_ts: Option<SystemTime>

Last rx timestamp associated with the last recvmsg call.

Implementations

Source

impl Stream

pub fn set_nodelay(&mut self) -> Result<()>

set TCP nodelay for this connection if self is TCP

pub fn set_keepalive(&mut self, ka: &TcpKeepalive) -> Result<()>

set TCP keepalive settings for this connection if self is TCP

pub fn set_rx_timestamp(&mut self) -> Result<()>

Available on Linux only.
pub fn rewind(&mut self, data: &[u8])

Put some data back to the head of the stream to be read again.

This is useful when you’ve read data to detect a protocol (e.g., PROXY protocol) but the data wasn’t what you expected, so you need to “unread” it.