GenBackgroundService

Struct GenBackgroundService 

pub struct GenBackgroundService<A> {
    pub threads: Option<usize>,
    /* private fields */
}
A generic type of background service

Fields

threads: Option<usize>

The number of threads. Default is 1

Implementations

Source

impl<A> GenBackgroundService<A>

pub fn new(name: String, task: Arc<A>) -> Self

Generates a background service that can run in the pingora runtime

pub fn task(&self) -> Arc<A>

Return the task behind Arc to be shared other logic.