ServiceReadyNotifier

Struct ServiceReadyNotifier 

pub struct ServiceReadyNotifier { /* private fields */ }
A notification channel for signaling when a service has become ready.

Services can use this to notify other services that may depend on them that they have successfully started and are ready to serve requests.

Example

use pingora_core::services::ServiceReadyNotifier;

async fn my_service(ready_notifier: ServiceReadyNotifier) {
    // Perform initialization...

    // Signal that the service is ready
    ready_notifier.notify_ready();

    // Continue with main service loop...
}

Implementations

Source

impl ServiceReadyNotifier

pub fn new(sender: Sender<bool>) -> Self

Creates a new ServiceReadyNotifier from a watch sender. You will not need to create one of these for normal usage, but being able to is useful for testing.

pub fn notify_ready(self)

Notifies dependent services that this service is ready.

Consumes the notifier to ensure ready is only signaled once.