pub struct Stream {
pub established_ts: SystemTime,
pub tracer: Option<Tracer>,
pub rx_ts: Option<SystemTime>,
/* private fields */
}Expand description
A concrete type for transport layer connection + extra fields for logging
Fields
established_ts: SystemTimeWhen this connection is established
tracer: Option<Tracer>The distributed tracing object for this stream
rx_ts: Option<SystemTime>Last rx timestamp associated with the last recvmsg call.
Implementations
Sourceimpl Stream
impl Stream
Sourcepub fn set_nodelay(&mut self) -> Result<()>
pub fn set_nodelay(&mut self) -> Result<()>
set TCP nodelay for this connection if self is TCP
Sourcepub fn set_keepalive(&mut self, ka: &TcpKeepalive) -> Result<()>
pub fn set_keepalive(&mut self, ka: &TcpKeepalive) -> Result<()>
set TCP keepalive settings for this connection if self is TCP
pub fn set_rx_timestamp(&mut self) -> Result<()>
Available on Linux only.