pub trait UniqueID {
// Required method
fn id(&self) -> UniqueIDType;
}Expand description
Define how a given session/connection identifies itself.
Required Methods
Sourcefn id(&self) -> UniqueIDType
fn id(&self) -> UniqueIDType
The ID returned should be unique among all existing connections of the same type. But ID can be recycled after a connection is shutdown.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl UniqueID for DuplexStream
impl UniqueID for DuplexStream
fn id(&self) -> UniqueIDType
Sourceimpl UniqueID for UnixStream
Available on Unix only.
impl UniqueID for UnixStream
Available on Unix only.