The service interface
A service to the pingora server is just something runs forever until the server is shutting down.
Two types of services are particularly useful
- services that are listening to some (TCP) endpoints
- services that are just running in the background.
Modules
- background
- The background service
- listening
- The listening service
Structs
- Service
Handle - A handle to a service in the server.
- Service
Ready Notifier - A notification channel for signaling when a service has become ready.
Traits
- Service
- The service interface
- Service
With Dependents
Type Aliases
- Service
Ready Watch - A receiver for watching when a service becomes ready.